event_count_by: Summarise adverse events by arm and other grouping variables
Description
event_count_by() creates a tabular summary of adverse events grouped by a
higher-level classification variable (e.g., system organ class), and counts
both the number of events and the number of unique patients per treatment arm.