powered by
dtlg
A convenience wrapper around print() for printing dtlg tables with consistent formatting options.
print()
print_dtlg( dt, row.names = FALSE, trunc.cols = TRUE, class = FALSE, nrows = Inf, justify = "left" )
Invisibly returns the printed object.
A dtlg table, typically a data.frame or data.table.
data.frame
data.table
If TRUE, row indices will be printed alongside x.
TRUE
x
If TRUE, only the columns that can be printed in the console without wrapping the columns to new lines will be printed (similar to tibbles).
tibbles
If TRUE, the resulting output will include above each column its storage class (or a self-evident abbreviation thereof).
The number of rows which will be printed before truncation is enforced.
String. Column alignment; one of "left", "right", "centre", or "none". Defaults to "left".
"left"
"right"
"centre"
"none"
calc_stats(dt = adsl, "AGE", treat = "ARM", indent = " ")[[1]] |> print_dtlg()
Run the code above in your browser using DataLab