The same output as summary_table() except that folded by variables
indicated in rows_by.
Arguments
dt
A data.frame containing, at least, the variables indicated in
target and treat.
target
Target variable passed as a string for which summary
statistics are to be calculated.
treat
A string indicating the grouping variable, e.g. the variable
specifying the treatment population.
rows_by
string, grouping variable to split events by.
indent
A string to be used as indentation of summary statistics
labels. Defaults to four HTML non-breaking spaces ( ).
.total_dt
Separate table from dt from which to derive total counts
per group.
pct_dec
Decimal places for reported figures.
treat_order
Customise the column order of the output table.
skip_absent
Whether to ignore variables passed in treat_order that
are absent from dt. Default is TRUE; FALSE will throw an error in
case there are missing variables.