vector of column names desired to obtain information on
treat
string of treatment variable used for splitting / grouping data
rows_by
string, grouping variable to split events by.
indent
indent to be used for display and formatting purposes
.total_dt
optional table for total counts to be derived
pct_dec
decimal places for percentages
treat_order
customise the column order of output table
skip_absent
Logical, default TRUE. Passed to data.table::setcolorder, if treat_order includes columns not present in dt, TRUE will silently ignore them, FALSE will throw an error.